@@ -34,6 +34,10 @@ class Pareto(object):
         '''
         inLevel=ratio>=1/self.oneOutOf
         return inLevel
+    
+    def asPercent(self):
+        percent=100.0/self.oneOutOf
+        return percent
             
     def __str__(self):
         text=self.asText(long=False)
@@ -44,5 +48,18 @@ class Pareto(object):
         if long:
             text=f"level {self.level}={text} (1 out of {self.oneOutOf})"
         return text
+    
+    def asDict(self)->dict:
+        '''
+        return me as a dict
+        
+        Returns:
+            dict: my values as a dict
+        '''
+        d={}
+        d["level"]=self.level
+        d["ratio"]=self.asText()
+        d["1 out of"]=self.oneOutOf
+        return d
         
         
\ No newline at end of file
